@@ -8,7 +8,7 @@ from sqlalchemy.schema import MetaData
 
 from guniflask_cli.sqlgen import SqlToModelGenerator
 from guniflask_cli.errors import UsageError
-from guniflask_cli.env import get_project_name_from_env
+from guniflask_cli.env import get_project_name_from_env, load_app_env
 from guniflask_cli.config import load_app_settings
 from .base import Command
 
@@ -38,12 +38,13 @@ class TableToModel(Command):
     def run(self, args):
         from guniflask.app import create_app
 
+        load_app_env()
         project_name = get_project_name_from_env()
         settings = load_app_settings(project_name)
 
-        app = create_app(project_name, settings=settings)
+        app = create_app(project_name, settings=settings, with_context=False)
         with app.app_context():
-            settings = app.extensions['settings']
+            settings = app.settings
             s = app.extensions.get('sqlalchemy')
             if not s:
                 raise UsageError('Not found SQLAlchemy')
@@ -54,14 +55,14 @@ class TableToModel(Command):
                 if b is None:
                     default_dest[b] = {'dest': join(project_name, 'models')}
                 else:
-                    default_dest[b] = {'dest': join(project_name, 'models_{}'.format(b))}
+                    default_dest[b] = {'dest': join(project_name, f'models_{b}')}
             dest_config = settings.get_by_prefix('guniflask.table2model_dest', default_dest)
-            if isinstance(default_dest, str):
+            if isinstance(dest_config, str):
                 default_dest[None]['dest'] = dest_config
             else:
                 for b in dest_config:
                     if b not in default_dest:
-                        raise UsageError('"{}" is not configured in binds'.format(b))
+                        raise UsageError(f'"{b}" is not configured in binds')
                     c = dest_config[b]
                     if isinstance(c, str):
                         default_dest[b]['dest'] = c
