@@ -5,27 +5,21 @@ from os.path import join, exists
 from collections import defaultdict
 from keyword import iskeyword
 import re
+import inspect
+from typing import Any, Union
 
 import sqlalchemy
 from sqlalchemy import ForeignKeyConstraint, UniqueConstraint, PrimaryKeyConstraint, CheckConstraint, ForeignKey
 import inflect
 from sqlalchemy.util import OrderedDict
 
-from .database_dialect import supported_dialects
 from .utils import string_camelcase, string_lowercase_underscore
 
-__all__ = ['SqlToModelGenerator']
-
 inflect_engine = inflect.engine()
 
 
 class SqlToModelGenerator:
     def __init__(self, name, metadata, indent=4, bind=None):
-        dialect_name = metadata.bind.dialect.name
-        if dialect_name not in supported_dialects:
-            raise ValueError('Unsupported dialect: {}'.format(dialect_name))
-
-        self.dialect = supported_dialects[dialect_name]
         self.name = name
         self.metadata = metadata
         self.indent = ' ' * indent
@@ -71,38 +65,40 @@ class SqlToModelGenerator:
         with open(join(path, '__init__.py'), 'w', encoding='utf-8') as f:
             f.write('# coding=utf-8\n\n')
             for m in model_modules:
-                f.write('from .{} import {}\n'.format(m['module'], m['class']))
+                f.write(f'from .{m["module"]} import {m["class"]}\n')
 
     def render_imports(self, model):
-        d = OrderedDict()
-        d.setdefault('guniflask.orm', 'BaseModelMixin')
+        collector = ImportCollector()
+        collector.add_import('BaseModelMixin', 'guniflask.orm')
+
         for col in model.table.columns:
             if col.server_default:
-                d.setdefault('sqlalchemy', ('text', '_text'))
+                collector.add_import(('text', '_text'), 'sqlalchemy')
+            collector.add_import(col.type)
 
         imports = ''
-        for k, v in d.items():
-            if isinstance(v, tuple):
-                imports += 'from {} import {} as {}\n'.format(k, v[0], v[1])
-            else:
-                imports += 'from {} import {}\n'.format(k, v)
-        if len(d) > 0:
+        for k, vlist in collector.items():
+            for v in vlist:
+                if isinstance(v, tuple):
+                    imports += f'from {k} import {v[0]} as {v[1]}\n'
+                else:
+                    imports += f'from {k} import {v}\n'
+        if len(collector) > 0:
             imports += '\n'
-        imports += 'from {} import db\n'.format(self.name)
+        imports += f'from {self.name} import db\n'
         return imports
 
     def render_model(self, model):
-        header_str = 'class {}(BaseModelMixin, db.Model):\n'.format(model.class_name)
-        header_str += "{}__tablename__ = '{}'\n".format(self.indent, model.table.name)
+        header_str = f'class {model.class_name}(BaseModelMixin, db.Model):\n'
+        header_str += f"{self.indent}__tablename__ = '{model.table.name}'\n"
         if self.bind:
-            header_str += "{}__bind_key__ = '{}'\n".format(self.indent, self.bind)
+            header_str += f"{self.indent}__bind_key__ = '{self.bind}'\n"
         header_str += '\n'
         columns_str = ''
         for col in model.table.columns:
             attr = convert_to_valid_identifier(col.name)
             show_name = attr != col.name
-            columns_str += '{}{} = {}\n'.format(self.indent, attr,
-                                                self.render_column(col, show_name=show_name))
+            columns_str += f'{self.indent}{attr} = {self.render_column(col, show_name=show_name)}\n'
         relationships_str = ''
         for r in model.relationships:
             relationships_str += self.indent + self.render_relationship(r) + '\n'
@@ -115,7 +111,7 @@ class SqlToModelGenerator:
     def render_table(self, table):
         columns_str = ',\n'.join(self.indent + self.render_column(col, show_name=True) for col in table.columns)
         tablename = convert_to_valid_identifier(table.name)
-        return '{} = db.Table({!r},\n{}\n)\n'.format(tablename, table.name, columns_str)
+        return f'{tablename} = db.Table({table.name!r},\n{columns_str}\n)\n'
 
     def render_column(self, column, show_name=False):
         is_sole_pk = column.primary_key and len(column.table.primary_key) == 1
@@ -146,28 +142,52 @@ class SqlToModelGenerator:
         if column.server_default:
             default_expr = self.get_compiled_expression(column.server_default.arg)
             if '\n' in default_expr:
-                server_default = 'server_default=text("""\\\n{0}""")'.format(default_expr)
+                server_default = f'server_default=_text("""\\\n{default_expr}""")'
             else:
                 default_expr = default_expr.replace('"', '\\"')
-                server_default = 'server_default=_text("{0}")'.format(default_expr)
-        extra_kwargs = self.get_extra_column_kwargs(column)
-        return "db.Column({})".format(', '.join(([repr(column.name)] if show_name else []) +
-                                                [self.render_column_type(column.type)] +
-                                                [self.render_constraint(x) for x in dedicated_fks] +
-                                                ['{}={!r}'.format(i, getattr(column, i)) for i in kwargs] +
-                                                ([server_default] if server_default else []) +
-                                                ['{}={}'.format(i, extra_kwargs[i]) for i in
-                                                 sorted(extra_kwargs.keys())]))
-
-    def get_extra_column_kwargs(self, column):
-        kwargs = {}
-        for p in supported_column_properties:
-            if p.match_column(column):
-                kwargs.update(p.kwargs)
-        return kwargs
+                server_default = f'server_default=_text("{default_expr}")'
+        return "db.Column({})".format(
+            ', '.join(
+                ([repr(column.name)] if show_name else []) +
+                [self.render_column_type(column.type)] +
+                [self.render_constraint(x) for x in dedicated_fks] +
+                [f'{i}={getattr(column, i)!r}' for i in kwargs] +
+                ([server_default] if server_default else [])
+            )
+        )
 
     def render_column_type(self, coltype):
-        return 'db.{}'.format(self.dialect.convert_column_type(coltype))
+        argspec = inspect.getfullargspec(coltype.__class__.__init__)
+        defaults = dict(zip(argspec.args[-len(argspec.defaults or ()):],
+                            argspec.defaults or ()))
+        args = []
+        kwargs = OrderedDict()
+        use_kwargs = False
+        missing = object()
+
+        for attr in argspec.args[1:]:
+            if attr.startswith('_'):
+                continue
+
+            value = getattr(coltype, attr, missing)
+            default = defaults.get(attr, missing)
+            if value is missing or value == default:
+                use_kwargs = True
+            elif use_kwargs:
+                kwargs[attr] = repr(value)
+            else:
+                args.append(repr(value))
+
+        if isinstance(coltype, sqlalchemy.Enum) and coltype.name is not None:
+            kwargs['name'] = repr(coltype.name)
+
+        for key, value in kwargs.items():
+            args.append('{}={}'.format(key, value))
+
+        rendered = coltype.__class__.__name__
+        if args:
+            rendered += f'({", ".join(args)})'
+        return rendered
 
     def render_constraint(self, constraint):
         def render_fk_options(*args):
@@ -175,19 +195,19 @@ class SqlToModelGenerator:
             for attr in 'ondelete', 'onupdate':
                 value = getattr(constraint, attr, None)
                 if value:
-                    opts.append('{}={!r}'.format(attr, value))
+                    opts.append(f'{attr}={value!r}')
             return ', '.join(opts)
 
         if isinstance(constraint, ForeignKey):
-            remote_column = '{}.{}'.format(constraint.column.table.name,
-                                           constraint.column.name)
-            return 'db.ForeignKey({})'.format(render_fk_options(remote_column))
+            remote_column = f'{constraint.column.table.name}.{constraint.column.name}'
+            return f'db.ForeignKey({render_fk_options(remote_column)})'
 
     def render_relationship(self, relationship):
-        kwargs_str = ', '.join([repr(table_name_to_class_name(relationship.target_tbl))] +
-                               ['{}={}'.format(i, relationship.kwargs[i]) for i in
-                                sorted(relationship.kwargs.keys())])
-        return '{} = db.relationship({})'.format(relationship.preferred_name, kwargs_str)
+        kwargs_str = ', '.join(
+            [repr(table_name_to_class_name(relationship.target_tbl))] +
+            [f'{i}={relationship.kwargs[i]}' for i in sorted(relationship.kwargs.keys())]
+        )
+        return f'{relationship.preferred_name} = db.relationship({kwargs_str})'
 
     def get_compiled_expression(self, statement):
         return str(statement.compile(
@@ -210,7 +230,7 @@ def table_name_to_class_name(table_name):
 
 def get_constraint_sort_key(constraint):
     if isinstance(constraint, CheckConstraint):
-        return 'C{0}'.format(constraint.sqltext)
+        return f'C{constraint.sqltext}'
     return constraint.__class__.__name__[0] + repr(list(constraint.columns.keys()))
 
 
@@ -263,7 +283,8 @@ class ManyToOneRelationship(Relationship):
         else:
             self.kwargs['lazy'] = repr('joined')
         self.kwargs['backref'] = "db.backref({}, lazy='joined')".format(
-            repr(convert_to_valid_identifier(source_tbl)))
+            repr(convert_to_valid_identifier(source_tbl))
+        )
         self.kwargs['cascade'] = repr('all, delete-orphan')
 
 
@@ -277,7 +298,8 @@ class ManyToManyRelationship(Relationship):
         self.kwargs['secondary'] = convert_to_valid_identifier(association_table.name)
         self.kwargs['lazy'] = repr('select')
         self.kwargs['backref'] = "db.backref({}, lazy='select')".format(
-            repr(inflect_engine.plural(convert_to_valid_identifier(source_tbl))))
+            repr(inflect_engine.plural(convert_to_valid_identifier(source_tbl)))
+        )
 
 
 class ColumnProperty:
@@ -288,25 +310,14 @@ class ColumnProperty:
         raise NotImplementedError
 
 
-class CreatedTimeProperty(ColumnProperty):
-    def __init__(self):
-        super().__init__()
-        self.kwargs['default'] = 'db.func.now()'
-        self.reg = re.compile(r'^create[d]?_(time|at)$')
-
-    def match_column(self, column):
-        return isinstance(column.type, sqlalchemy.DateTime) and self.reg.match(column.name.lower()) is not None
-
-
-class UpdatedTimeProperty(ColumnProperty):
-    def __init__(self):
-        super().__init__()
-        self.kwargs['default'] = 'db.func.now()'
-        self.kwargs['onupdate'] = 'db.func.now()'
-        self.reg = re.compile(r'^update[d]?_(time|at)$')
-
-    def match_column(self, column):
-        return isinstance(column.type, sqlalchemy.DateTime) and self.reg.match(column.name.lower()) is not None
-
-
-supported_column_properties = [CreatedTimeProperty(), UpdatedTimeProperty()]
+class ImportCollector(OrderedDict):
+    def add_import(self, name: Any, pkg: Union[str, tuple] = None):
+        if not isinstance(name, (str, tuple)):
+            if inspect.isclass(name):
+                obj_type = name
+            else:
+                obj_type = type(name)
+            pkg = obj_type.__module__
+            name = obj_type.__name__
+        names = self.setdefault(pkg, set())
+        names.add(name)
