@@ -97,8 +97,10 @@ def redirect_logger(name, logger):
     log = logging.getLogger(name)
     log.handlers = logger.handlers
     log.setLevel(logger.level)
+    log.propagate = False
 
 
 def redirect_app_logger(app: Flask, logger):
     app.logger.handlers = logger.handlers
     app.logger.setLevel(logger.level)
+    app.logger.propagate = False
